# Trans-Omics Acceleration Library

## Introduction
The Trans-Omics Acceleration Library (TAL) contains key modules for Trans-Omics analysis that are optimized for Xeon.

The contributors to TAL are Sanchit Misra, Vasimuddin Md, Saurabh Kalikar, Narendra Chaudhary and Kanak Mahadik.

## Getting Started
```sh
git clone --recursive <REPO URL>
make
```

## Publications

Vasimuddin Md, Sanchit Misra, Heng Li, Srinivas Aluru.
<b> Efficient Architecture-Aware Acceleration of BWA-MEM for Multicore Systems. </b>
<i> IEEE Parallel and Distributed Processing Symposium (IPDPS), 2019. </i>

Sanchit Misra, Tony  Pan, Kanak  Mahadik, George  Powley, Priya N Vaidya, Md  Vasimuddin, Srinivas  Aluru.
<b> Performance extraction and suitability analysis of multi- and many-core architectures for next generation sequencing secondary analysis. </b>
<i> International Conference on Parallel Architectures and Compilation Techniques (PACT), 2018. </i>
